import * as appscaling from '@aws-cdk/aws-applicationautoscaling';
import * as backup from '@aws-cdk/aws-backup';
import * as ec2 from '@aws-cdk/aws-ec2';
import * as ecs from '@aws-cdk/aws-ecs';
import * as efs from '@aws-cdk/aws-efs';
import * as cdk from '@aws-cdk/core';
/**
 * Options for ValheimWorldScalingSchedule.
 *
 * @stability stable
 */
export interface ValheimWorldScalingScheduleProps {
    /**
     * Options to configure a cron expression for server for server launching schedule.
     *
     * All fields are strings so you can use complex expressions. Absence of
     * a field implies '*' or '?', whichever one is appropriate. Only comma
     * separated numbers and hypens are allowed.
     *
     * @stability stable
     */
    readonly startAt: appscaling.CronOptions;
    /**
     * Options to configure a cron expression for server zero-scale schedule.
     *
     * All fields are strings so you can use complex expressions. Absence of
     * a field implies '*' or '?', whichever one is appropriate. Only comma
     * separated numbers and hypens are allowed.
     *
     * @stability stable
     */
    readonly stopAt: appscaling.CronOptions;
}
/**
 * @stability stable
 */
export interface ValheimWorldProps {
    /**
     * The VPC where your ECS instances will be running or your ENIs will be deployed.
     *
     * @default - creates a new VPC with two AZs
     * @stability stable
     */
    readonly vpc?: ec2.IVpc;
    /**
     * Persistent storage for save data.
     *
     * @default - Amazon EFS for default persistent storage.
     * @stability stable
     */
    readonly fileSystem?: efs.FileSystem;
    /**
     * AWS Backup plan for EFS.
     *
     * @default - Hourly backup with 3 days retension.
     * @stability stable
     */
    readonly backupPlan?: backup.BackupPlan;
    /**
     * @stability stable
     */
    readonly image?: ecs.ContainerImage;
    /**
     * The number of cpu units used by the task.
     *
     * For tasks using the Fargate launch type,
     * this field is required and you must use one of the following values,
     * which determines your range of valid values for the memory parameter:
     *
     * 256 (.25 vCPU) - Available memory values: 512 (0.5 GB), 1024 (1 GB), 2048 (2 GB)
     *
     * 512 (.5 vCPU) - Available memory values: 1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB)
     *
     * 1024 (1 vCPU) - Available memory values: 2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB)
     *
     * 2048 (2 vCPU) - Available memory values: Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB)
     *
     * 4096 (4 vCPU) - Available memory values: Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB)
     *
     * @default 1024
     * @stability stable
     */
    readonly cpu?: number;
    /**
     * The amount (in MiB) of memory used by the task.
     *
     * For tasks using the Fargate launch type,
     * this field is required and you must use one of the following values, which determines your range of valid values for the cpu parameter:
     *
     * 512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) - Available cpu values: 256 (.25 vCPU)
     *
     * 1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) - Available cpu values: 512 (.5 vCPU)
     *
     * 2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) - Available cpu values: 1024 (1 vCPU)
     *
     * Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB) - Available cpu values: 2048 (2 vCPU)
     *
     * Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB) - Available cpu values: 4096 (4 vCPU)
     *
     * @default 2048
     * @stability stable
     */
    readonly memoryLimitMiB?: number;
    /**
     * Desired count of Fargate container.
     *
     * Set 0 for maintenance.
     *
     * @default - 1
     * @stability stable
     */
    readonly desiredCount?: number;
    /**
     * https://github.com/lloesche/valheim-server-docker#environment-variables.
     *
     * @stability stable
     */
    readonly environment?: {
        [key: string]: string;
    };
    /**
     * Valheim Server log Group.
     *
     * @default - Create the new AWS Cloudwatch Log Group for Valheim Server.
     * @stability stable
     */
    readonly logGroup?: ecs.LogDriver;
    /**
     * Running schedules.
     *
     * @default - Always running.
     * @stability stable
     */
    readonly schedules?: ValheimWorldScalingScheduleProps[];
}
/**
 * Represents the schedule to determine when the server starts or terminates.
 *
 * @stability stable
 */
export declare class ValheimWorldScalingSchedule {
    private static range;
    private static toIntArraySorted;
    /**
     * Options to configure a cron expression for server for server launching schedule.
     *
     * All fields are strings so you can use complex expressions. Absence of
     * a field implies '*' or '?', whichever one is appropriate. Only comma
     * separated numbers and hypens are allowed.
     *
     * @stability stable
     */
    readonly startAt: appscaling.CronOptions;
    /**
     * Options to configure a cron expression for server zero-scale schedule.
     *
     * All fields are strings so you can use complex expressions. Absence of
     * a field implies '*' or '?', whichever one is appropriate. Only comma
     * separated numbers and hypens are allowed.
     *
     * @stability stable
     */
    readonly stopAt: appscaling.CronOptions;
    /**
     * @stability stable
     */
    constructor(schedule: ValheimWorldScalingScheduleProps);
    private toCron;
    private toCronHour;
    private toCronWeekDay;
    /**
     * Returns the cron option merged both startAt and endAt.
     *
     * @stability stable
     */
    toCronOptions(): appscaling.CronOptions;
}
/**
 * @stability stable
 */
export declare class ValheimWorld extends cdk.Construct {
    /**
     * @stability stable
     */
    backupPlan: backup.BackupPlan;
    /**
     * @stability stable
     */
    fileSystem: efs.FileSystem;
    /**
     * @stability stable
     */
    schedules?: ValheimWorldScalingSchedule[];
    /**
     * @stability stable
     */
    service: ecs.FargateService;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props?: ValheimWorldProps);
    private defaultBackupPlan;
}
